==> react-native-ui-xep-0.1.37.tgz: package/src/atoms/input/TextArea.tsx <==
import React, { FC } from 'react';
import {
  Textarea as TextareaX,
  Item,
  Label,
  NativeBase,
  RnViewStyleProp,
} from 'native-base';
import { styles } from './styles';
import {
  borderedInputVariables,
  primaryInputVariables,
} from '../../Configurations/ThemeConfig';

type Props = NativeBase.Textarea & {
  type?: 'material' | 'material-black'  |'primary' | 'bordered';
  TextareaStyle?: any;
  label?: string;
  style?: RnViewStyleProp;
  labelProps?: NativeBase.Label;
  TextareaProps?: NativeBase.Textarea;
  shadow?: boolean;
  // children: ReactNode;
};
export const Textarea: FC<Props> = (props: Props) => {
  const { type, label, labelProps, style, TextareaStyle, shadow } = props;
  const propsX = { ...props };
  propsX.style = TextareaStyle;
  delete propsX.labelProps;
  delete propsX.type;
  delete propsX.label;
  delete propsX.TextareaStyle;

  const renderElement = (
    inputStyleX?: any,
    labelStyle?: any,
    placeholderTextColor?: string
  ) => {
    inputStyleX = shadow ? { ...inputStyleX, ...styles.shadow } : inputStyleX;
    return (
      <Item
        stackedLabel={label !== undefined}
        style={
          style !== undefined
            ? { ...styles.itemStyle, ...(style as object) }
            : styles.itemStyle
        }
      >
        {label && (
          <Label
            {...labelProps}
            style={
              labelProps?.style
                ? { ...labelStyle, ...(labelProps.style as object) }
                : labelStyle
            }
          >
            {label}
          </Label>
        )}

        <TextareaX
          {...propsX}
          placeholderTextColor={placeholderTextColor ?? '#C4C4C4'}
          style={
            TextareaStyle ? { ...inputStyleX, ...TextareaStyle } : inputStyleX
          }
        />
      </Item>
    );
  };
  switch (type) {
    case 'material':
      return renderElement(styles.material, styles.textMaterial);
    case 'material-black':
      return renderElement( styles.materialBlack,
        { ...styles.textMaterial, color: 'black' },);
    case 'bordered':
      return renderElement(
        styles.bordered,
        {
          ...styles.textDefault,
          color: '#979797',
          marginLeft: 10,
          fontWeight: 'bold',
        },
        borderedInputVariables.placeholderColor
      );
    default:
      return renderElement(
        styles.default,
        styles.textDefault,
        primaryInputVariables.placeholderColor
      );
  }
};

==> react-native-ui-xep-0.1.38.tgz: package/src/atoms/input/TextArea.tsx <==
import React, { FC } from 'react';
import {
  Textarea as TextareaX,
  Item,
  Label,
  NativeBase,
  RnViewStyleProp,
} from 'native-base';
import { styles } from './styles';
import {
  borderedInputVariables,
  primaryInputVariables,
} from '../../Configurations/ThemeConfig';

type Props = NativeBase.Textarea & {
  type?: 'material' | 'material-black' | 'primary' | 'bordered';
  TextareaStyle?: any;
  label?: string;
  style?: RnViewStyleProp;
  labelProps?: NativeBase.Label;
  TextareaProps?: NativeBase.Textarea;
  shadow?: boolean;
  // children: ReactNode;
};
export const Textarea: FC<Props> = (props: Props) => {
  const { type, label, labelProps, style, TextareaStyle, shadow } = props;
  const propsX = { ...props };
  propsX.style = TextareaStyle;
  delete propsX.labelProps;
  delete propsX.type;
  delete propsX.label;
  delete propsX.TextareaStyle;

  const renderElement = (
    inputStyleX?: any,
    labelStyle?: any,
    placeholderTextColor?: string
  ) => {
    inputStyleX = shadow ? { ...inputStyleX, ...styles.shadow } : inputStyleX;
    return (
      <Item
        stackedLabel={label !== undefined}
        style={
          style !== undefined
            ? { ...styles.itemStyle, ...(style as object) }
            : styles.itemStyle
        }
      >
        {label && (
          <Label
            {...labelProps}
            style={
              labelProps?.style
                ? { ...labelStyle, ...(labelProps.style as object) }
                : labelStyle
            }
          >
            {label}
          </Label>
        )}

        <TextareaX
          {...propsX}
          placeholderTextColor={placeholderTextColor ?? '#C4C4C4'}
          style={
            TextareaStyle ? { ...inputStyleX, ...TextareaStyle } : inputStyleX
          }
        />
      </Item>
    );
  };
  switch (type) {
    case 'material':
      return renderElement(styles.material, styles.textMaterial);
    case 'material-black':
      return renderElement(styles.materialBlack, {
        ...styles.textMaterial,
        color: 'black',
      });
    case 'bordered':
      return renderElement(
        styles.bordered,
        {
          ...styles.textDefault,
          color: '#979797',
          marginLeft: 10,
          fontWeight: 'bold',
        },
        borderedInputVariables.placeholderColor
      );
    default:
      return renderElement(
        styles.default,
        styles.textDefault,
        primaryInputVariables.placeholderColor
      );
  }
};
